#!/usr/bin/python3
# -*- coding: utf-8 -*-
# (c) B.Kerler 2018-2021 MIT License
ErrorCodes = {
    0x0: "OK",
    0x1000: "CRYPTO_INIT_FAIL",
    0x1001: "CRYPTO_DEINIT_FAIL",
    0x1002: "CRYPTO_MODE_INVALID",
    0x1003: "CRYPTO_KEY_INVALID",
    0x1004: "CRYPTO_DATA_UNALIGNED",
    0X1005: "CRYPTO_SEEK_LEN_ERROR",
    0x1D00: "ADDRESS_TOO_HIGH_80000000",
    0x1D01: "ADDRESS_TOO_HIGH_40000000",
    0x1D02: "INVALID_ADDRESS",
    0x1D0C: "",
    0x1D0D: "SLA_ERROR",
    0x1D0E: "DA_OVERLAP",
    0x1D0F: "DA_INVALID_JUMP_ADDR",
    0x1D10: "DA_EXCEED_MAX_DA_BLOCKS",
    0x1D11: "DA_ADDR_NOT_16BITS_ALIGNED",
    0x1D12: "DA_INVALID_ADDR_AND_LEN",
    0x1D13: "DA_LEN_IS_ZERO",
    0x1D14: "DA_SIG_LEN_EXCEED_DA_LEN",
    0x1D15: "DA_SIG_LEN_IS_ZERO_AND_DAA_ACTIVE",
    0x1D16: "DA_NOT_EXIST",
    0x1D17: "DA_BLOCKS_INCONSISTENT_WITH_TOOL_AUTH",
    0x1D21: "DA_VERSION_NOT_SUPPORTED",
    0x2000: "AUTH_IMAGE_VERIFY_FAIL",
    0x2001: "DA_IMAGE_SIG_VERIFY_FAIL",
    0x2002: "DA_IMAGE_NO_MEM_FAIL",
    0x2003: "DA_INIT_KEY_FAIL",
    0x2004: "IMG_INIT_KEY_FAIL",
    0x2005: "HASH_IMAGE_FAIL",
    0x2006: "DA_RELOCATE_SIZE_NOT_ENOUGH",
    0x3000: "LIB_SEC_CFG_NOT_EXIST",
    0x3001: "LIB_VER_INVALID",
    0x3002: "LIB_SEC_CFG_ERASE_FAIL",
    0x3003: "LIB_SEC_CFG_CANNOT_WRITE",
    0x3004: "LIB_SEC_CFG_END_PATTERN_NOT_EXIST",
    0x3005: "LIB_SEC_CFG_STATUS_INVALID",
    0x3006: "LIB_SEC_CFG_READ_SIZE_NOT_ENOUGH",
    0x3007: "LIB_SEC_CFG_RSA_KEY_INIT_FAIL",
    0x4000: "IMG_VERIFY_THIS_IMG_INFO_NOT_EXIST",
    0x4001: "IMG_VERIFY_HASH_COMPARE_FAIL",
    0x4002: "IMG_VERIFY_NO_SPACE_ADD_IMG_INFO",
    0x4003: "SEC_DL_TOKEN_NOT_FOUND_IN_IMG",
    0x4004: "SEC_DL_FLOW_ERROR",
    0x4005: "IMG_VERIFY_INVALID_IMG_INFO_ATTR",
    0x4006: "IMG_SECROIMG_NOT_FOUND",
    0x4007: "IMG_READ_FAIL",
    0x4008: "IMG_VERIFY_SIGNATURE_FAIL",
    0x4009: "IMG_SIGN_FORMAT_NOT_MATCH",
    0x400A: "IMG_EXTENSION_HDR_NOT_FOUND",
    0x400B: "IMG_EXTENSION_MAGIC_WRONG",
    0x400C: "IMG_EXTENSION_TYPE_NOT_SUPPORT",
    0x400D: "IMG_EXTENSION_HASH_CAL_FAIL",
    0x5000: "IMG_LOCK_TABLE_NOT_EXIST",
    0x5001: "IMG_LOCK_ALL_LOCK",
    0x5002: "IMG_LOCK_NO_SPACE_ADD_LOCK_INFO",
    0x5003: "IMG_LOCK_THIS_IMG_INFO_NOT_EXIST",
    0x5004: "IMG_LOCK_MAGIC_ERROR",
    0x6000: "SBC_KEY_NOT_FOUND",
    0x6001: "BR_SEC_CFG_NOT_FOUND",
    0x7000: "REGION_INVALID_INCLUDE",
    0x7001: "REGION_INVALID_OVERLAP",
    0x7002: "REGION_INVALID_OVERFLOW",
    0x7003: "DA_INVALID_LOCATION",
    0x7004: "DA_INVALID_LENGTH",
    0x7015: "DAA_Security_Error_Signature",
    0x7017: "DAA_Security_Error",
    0x7024: "DAA_SIG_VERIFY_FAILED",
    0x8000: "INVALID_SIG_SZ",
    0x8001: "INVALID_PADDING_SZ",
    0x9000: "SW_ID_MISMATCH",
    0x9001: "INVALID_IMG_TYPE",
    0x9002: "BUF_NOT_ENOUGH_FOR_CERT",
    0x9003: "IMG_NOT_FOUND",
    0x9004: "IMG_HDR_HASH_VFY_FAIL",
    0x9005: "IMG_HASH_VFY_FAIL",
    0x9006: "INVALID_OID_SZ",
    0x9007: "INVALID_OID_BUF_SZ",
    0x9008: "END_OF_CERT",
    0x9009: "CERT_OBJ_ID_NOT_MATCH",
    0x900a: "CERT_OBJ_SZ_NOT_MATCH",
    0x900b: "CERT_TRAVERSE_UNKNOWN_MODE",
    0x900c: "INVALID_OID_IDX",
    0x900d: "OID_NOT_FOUND",
    0x900e: "OBJ_NOT_FOUND",
    0x900f: "E_KEY_LEN_NOT_MATCH",
    0x9010: "E_KEY_NOT_MATCH",
    0x9011: "N_KEY_LEN_NOT_MATCH",
    0x9012: "N_KEY_NOT_MATCH",
    0x9013: "PUBK_AUTH_FAIL",
    0x9014: "INVALID_IMG_HDR",
    0x9015: "NOT_EXPECTED_IMG",
    0xA000: "CERT_IMG_VER_NOT_SYNC",
    0xA001: "IMAGE_IMG_VER_NOT_SYNC",
    0xA002: "IMG_VER_ROLLBACK",
    0xA003: "OTP_FIELD_NOT_ENOUGH",
    0xA004: "OTP_REG_BIT_CONFIG_WRONG",
    0xA005: "OTP_WRITE_FAIL"
}


class ErrorHandler:
    def __init__(self):
        self.ec = ErrorCodes

    def status(self, status):
        if status in self.ec:
            return self.ec[status]
        else:
            return "Unknown: " + hex(status)
